pls take a look at @SPECS.md and all the specs file in .project/specs

also take a look at src/flock/core and examples/01... and /02... for the most important code

Please report back if you have a deep understanding of the codebase to talk about the next steps